Django-Authenticated-Signals
======================

The Django-Authenticated-Signals package provides several specialized model save and delete signals
with additional `request` parameter.

See details at the home page: https://github.com/nnseva/django-authenticated-signals
